@@ -20,6 +20,7 @@ sub run {
     my $version;
     my $text;
     my $metacpan;
+    my $simple = 0;
 
     my $p = Getopt::Long::Parser->new(
         config => [qw(posix_default no_ignore_case auto_help)] );
@@ -28,6 +29,7 @@ sub run {
             'metacpan!' => \$metacpan,
             'version!'  => \$version,
             'text!'     => \$text,
+            'simple!'   => \$simple,
         )
     );
     if ($version) {
@@ -36,10 +38,10 @@ sub run {
     my $directory = shift @args or pod2usage(
         -input => $0,
     );
-
     my $orepan = OrePAN2::Indexer->new(
         directory => $directory,
         metacpan  => $metacpan,
+        simple    => $simple,
     );
     $orepan->make_index(
         no_compress => $text,
